Aydin Denoising Spinning-Disk Confocal Microscopy Images of Mouse Embryos from the Maitre Lab (Curie, Paris)
================================================================================================================


.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vSGUTI3ug6shZscvM-nO4F4-FxJqDILoX-sqVXY4Be4FeMzDar-jvKuGh-RYgW8f84o4bg9aaRrDyo4/pub?embedded=true" height="6180" width="720"></iframe>

